==> sdd.debin-jar-0.2.20-sources.jar: ar/com/sdd/debin/io/CompradorRecurrenciaListaCompradorRequest.java <==
package ar.com.sdd.debin.io;

import ar.com.sdd.debin.entity.Comprador;
import ar.com.sdd.debin.entity.Creacion;
import ar.com.sdd.debin.entity.Estado;
import ar.com.sdd.debin.entity.Listado;
import ar.com.sdd.debin.entity.Vendedor;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;

@JsonIgnoreProperties(ignoreUnknown = true)
@JsonInclude(JsonInclude.Include.NON_NULL)
public class CompradorRecurrenciaListaCompradorRequest {

    private Listado listado;
    private Creacion creacion;
    private Comprador comprador;
    private Vendedor vendedor;
    private Estado estado;

    public CompradorRecurrenciaListaCompradorRequest() {
    }

    public Listado getListado() {
        return listado;
    }

    public void setListado(Listado listado) {
        this.listado = listado;
    }

    public Creacion getCreacion() {
        return creacion;
    }

    public void setCreacion(Creacion creacion) {
        this.creacion = creacion;
    }

    public Comprador getComprador() {
        return comprador;
    }

    public void setComprador(Comprador comprador) {
        this.comprador = comprador;
    }

    public Vendedor getVendedor() {
        return vendedor;
    }

    public void setVendedor(Vendedor vendedor) {
        this.vendedor = vendedor;
    }

    public Estado getEstado() {
        return estado;
    }

    public void setEstado(Estado estado) {
        this.estado = estado;
    }

    @Override
    public String toString() {
        return "CompradorRecurrenciaListaCompradorRequest [" +
                "listado=" + listado +
                ", creacion=" + creacion +
                ", comprador=" + comprador +
                ", vendedor=" + vendedor +
                ", estado=" + estado +
                ']';
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        CompradorRecurrenciaListaCompradorRequest that = (CompradorRecurrenciaListaCompradorRequest) o;

        if (listado != null ? !listado.equals(that.listado) : that.listado != null) return false;
        if (creacion != null ? !creacion.equals(that.creacion) : that.creacion != null) return false;
        if (comprador != null ? !comprador.equals(that.comprador) : that.comprador != null) return false;
        if (vendedor != null ? !vendedor.equals(that.vendedor) : that.vendedor != null) return false;
        return estado != null ? estado.equals(that.estado) : that.estado == null;
    }

    @Override
    public int hashCode() {
        int result = listado != null ? listado.hashCode() : 0;
        result = 31 * result + (creacion != null ? creacion.hashCode() : 0);
        result = 31 * result + (comprador != null ? comprador.hashCode() : 0);
        result = 31 * result + (vendedor != null ? vendedor.hashCode() : 0);
        result = 31 * result + (estado != null ? estado.hashCode() : 0);
        return result;
    }
}

==> sdd.debin-jar-0.2.21-sources.jar: ar/com/sdd/debin/io/CompradorRecurrenciaListaCompradorRequest.java <==
package ar.com.sdd.debin.io;

import ar.com.sdd.debin.entity.Comprador;
import ar.com.sdd.debin.entity.Creacion;
import ar.com.sdd.debin.entity.Estado;
import ar.com.sdd.debin.entity.Listado;
import ar.com.sdd.debin.entity.Vendedor;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import javax.json.bind.annotation.JsonbNillable;

@JsonIgnoreProperties(ignoreUnknown = true)
@JsonbNillable
public class CompradorRecurrenciaListaCompradorRequest {

    private Listado listado;
    private Creacion creacion;
    private Comprador comprador;
    private Vendedor vendedor;
    private Estado estado;

    public CompradorRecurrenciaListaCompradorRequest() {
    }

    public Listado getListado() {
        return listado;
    }

    public void setListado(Listado listado) {
        this.listado = listado;
    }

    public Creacion getCreacion() {
        return creacion;
    }

    public void setCreacion(Creacion creacion) {
        this.creacion = creacion;
    }

    public Comprador getComprador() {
        return comprador;
    }

    public void setComprador(Comprador comprador) {
        this.comprador = comprador;
    }

    public Vendedor getVendedor() {
        return vendedor;
    }

    public void setVendedor(Vendedor vendedor) {
        this.vendedor = vendedor;
    }

    public Estado getEstado() {
        return estado;
    }

    public void setEstado(Estado estado) {
        this.estado = estado;
    }

    @Override
    public String toString() {
        return "CompradorRecurrenciaListaCompradorRequest [" +
                "listado=" + listado +
                ", creacion=" + creacion +
                ", comprador=" + comprador +
                ", vendedor=" + vendedor +
                ", estado=" + estado +
                ']';
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        CompradorRecurrenciaListaCompradorRequest that = (CompradorRecurrenciaListaCompradorRequest) o;

        if (listado != null ? !listado.equals(that.listado) : that.listado != null) return false;
        if (creacion != null ? !creacion.equals(that.creacion) : that.creacion != null) return false;
        if (comprador != null ? !comprador.equals(that.comprador) : that.comprador != null) return false;
        if (vendedor != null ? !vendedor.equals(that.vendedor) : that.vendedor != null) return false;
        return estado != null ? estado.equals(that.estado) : that.estado == null;
    }

    @Override
    public int hashCode() {
        int result = listado != null ? listado.hashCode() : 0;
        result = 31 * result + (creacion != null ? creacion.hashCode() : 0);
        result = 31 * result + (comprador != null ? comprador.hashCode() : 0);
        result = 31 * result + (vendedor != null ? vendedor.hashCode() : 0);
        result = 31 * result + (estado != null ? estado.hashCode() : 0);
        return result;
    }
}
